Rename BasePlugin to Longcat.

for lolz

Signed-off-by: Jonny Lamb <jonny.lamb@collabora.co.uk>

# Please enter the commit message for your changes. Lines starting
# with '#' will be ignored, and an empty message aborts the commit.
# On branch master
# Changes to be committed:
#   (use "git reset HEAD <file>..." to unstage)
#
#	modified:   .gitignore
#	modified:   data/Makefile.am
#	renamed:    data/base-advanced.glade -> data/longcat-advanced.glade
#	modified:   debian/control
#	deleted:    debian/libbase-plugin0.install
#	new file:   debian/liblongcat0.install
#	modified:   debian/rules
#	modified:   src/Makefile.am
#	deleted:    src/base-plugin.h
#	modified:   src/butterfly-plugin.c
#	modified:   src/butterfly-plugin.h
#	modified:   src/haze-plugin.c
#	modified:   src/haze-plugin.h
#	modified:   src/idle-plugin.c
#	modified:   src/idle-plugin.h
#	renamed:    src/base-plugin.c -> src/longcat.c
#	new file:   src/longcat.h
#	modified:   src/salut-plugin.c
#	modified:   src/salut-plugin.h
#
diff --git a/.gitignore b/.gitignore
index dd150c9..a722516 100644
--- a/.gitignore
+++ b/.gitignore
@@ -39,9 +39,9 @@ debian/account-plugin-salut-dbg/
 debian/account-plugin-salut.substvars
 debian/account-plugin-salut/
 debian/files
-debian/libbase-plugin-dbg/
-debian/libbase-plugin0.substvars
-debian/libbase-plugin0/
+debian/liblongcat-dbg/
+debian/liblongcat0.substvars
+debian/liblongcat0/
 debian/stamp-autotools-files
 debian/stamp-makefile-build
 debian/telepathy-extras/
diff --git a/data/Makefile.am b/data/Makefile.am
index 7da5112..5b56e64 100644
--- a/data/Makefile.am
+++ b/data/Makefile.am
@@ -1,6 +1,6 @@
 pluginxmldir = $(pluginlibdir)/xml
 pluginxml_DATA = \
-	base-advanced.glade
+	longcat-advanced.glade
 
 profile_DATA = \
 	       aim.profile \
diff --git a/data/base-advanced.glade b/data/longcat-advanced.glade
similarity index 100%
rename from data/base-advanced.glade
rename to data/longcat-advanced.glade
diff --git a/debian/control b/debian/control
index eb95702..1b0d51d 100644
--- a/debian/control
+++ b/debian/control
@@ -11,7 +11,7 @@ Description: Metapackage for all the extra telepathy packages and account plugin
  This package is merely for pulling in all the optional Telepathy packages and their
  account plugins.
 
-Package: libbase-plugin0
+Package: liblongcat0
 Architecture: any
 Section: libs
 Depends: ${shlibs:Depends}, ${misc:depends}
@@ -19,7 +19,7 @@ Description: Base plugin for the Accounts user interface
  A base plugin for writing accounts plugins, which makes it easier and need
  less code.
 
-Package: libbase-plugin-dbg
+Package: liblongcat-dbg
 Architecture: any
 Section: libs
 Depends: ${shlibs:Depends}, ${misc:depends}
@@ -32,7 +32,7 @@ Description: Base plugin for the Accounts user interface
 Package: account-plugin-haze
 Architecture: any
 Section: user/communication
-Depends: ${shlibs:Depends}, ${misc:depends}, libbase-plugin0 (= ${source:Version}), telepathy-haze, purple-protocol-sametime
+Depends: ${shlibs:Depends}, ${misc:depends}, liblongcat0 (= ${source:Version}), telepathy-haze, purple-protocol-sametime
 Description: Haze plugin for the Accounts user interface
  A plugin for configuring accounts supported by libpurple. The plugin allows
  plugins from the following protocols:
@@ -69,7 +69,7 @@ Description: Haze plugin for the Accounts user interface -- debug symbols
 Package: account-plugin-salut
 Architecture: any
 Section: user/communication
-Depends: ${shlibs:Depends}, ${misc:depends}, libbase-plugin0 (= ${source:Version}), telepathy-salut
+Depends: ${shlibs:Depends}, ${misc:depends}, liblongcat0 (= ${source:Version}), telepathy-salut
 Description: Salut plugin for the Accounts user interface
  A plugin for configuring link-local XMPP accounts using the telepathy-salut
  connection manager.
@@ -88,7 +88,7 @@ Description: Salut plugin for the Accounts user interface -- debug symbols
 Package: account-plugin-butterfly
 Architecture: any
 Section: user/communication
-Depends: ${shlibs:Depends}, ${misc:depends}, libbase-plugin0 (= ${source:Version}), telepathy-butterfly
+Depends: ${shlibs:Depends}, ${misc:depends}, liblongcat0 (= ${source:Version}), telepathy-butterfly
 Description: Butterfly plugin for the Accounts user interface
  A plugin for configuring accounts supported by telepathy-butterfly. The plugin allows
  plugins from the MSN service.
@@ -107,7 +107,7 @@ Description: Butterfly plugin for the Accounts user interface -- debug symbols
 Package: account-plugin-idle
 Architecture: any
 Section: user/communication
-Depends: ${shlibs:Depends}, ${misc:depends}, libbase-plugin0 (= ${source:Version}), telepathy-idle
+Depends: ${shlibs:Depends}, ${misc:depends}, liblongcat0 (= ${source:Version}), telepathy-idle
 Description: Idle plugin for the Accounts user interface
  A plugin for configuring accounts supported by telepathy-idle. The plugin allows
  one to configuring IRC accounts.
diff --git a/debian/libbase-plugin0.install b/debian/libbase-plugin0.install
deleted file mode 100644
index f039348..0000000
--- a/debian/libbase-plugin0.install
+++ /dev/null
@@ -1,2 +0,0 @@
-usr/lib/libaccounts-plugins/libbase-plugin*so*
-usr/lib/libaccounts-plugins/xml/base-advanced.glade
diff --git a/debian/liblongcat0.install b/debian/liblongcat0.install
new file mode 100644
index 0000000..7346216
--- /dev/null
+++ b/debian/liblongcat0.install
@@ -0,0 +1,2 @@
+usr/lib/libaccounts-plugins/liblongcat*so*
+usr/lib/libaccounts-plugins/xml/longcat-advanced.glade
diff --git a/debian/rules b/debian/rules
index 40f0f34..b991044 100755
--- a/debian/rules
+++ b/debian/rules
@@ -7,7 +7,7 @@ DEB_DH_INSTALL_SOURCEDIR=debian/tmp
 DEB_DESTDIR=$(CURDIR)/debian/tmp
 DEB_DH_MAKESHLIBS_ARGS := --exclude=plugin --exclude=applet
 
-DEB_DBG_PACKAGE_libbase-plugin0 = libbase-plugin-dbg
+DEB_DBG_PACKAGE_liblongcat0 = liblongcat-dbg
 DEB_DBG_PACKAGE_account-plugin-haze = account-plugin-haze-dbg
 DEB_DBG_PACKAGE_account-plugin-butterfly = account-plugin-butterfly-dbg
 DEB_DBG_PACKAGE_account-plugin-idle = account-plugin-idle-dbg
diff --git a/src/Makefile.am b/src/Makefile.am
index 085d334..860e1c3 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -1,5 +1,5 @@
 pluginlib_LTLIBRARIES = \
-	libbase-plugin.la \
+	liblongcat.la \
 	libhaze-plugin.la \
 	libbutterfly-plugin.la \
 	libidle-plugin.la \
@@ -7,38 +7,38 @@ pluginlib_LTLIBRARIES = \
 
 libhaze_plugin_ladir = $(pluginlibdir)
 libhaze_plugin_la_LIBADD = \
-	libbase-plugin.la
+	liblongcat.la
 libhaze_plugin_la_SOURCES = \
 	haze-plugin.h	\
 	haze-plugin.c
 
 libbutterfly_plugin_ladir = $(pluginlibdir)
 libbutterfly_plugin_la_LIBADD = \
-	libbase-plugin.la
+	liblongcat.la
 libbutterfly_plugin_la_SOURCES = \
 	butterfly-plugin.h	\
 	butterfly-plugin.c
 
 libidle_plugin_ladir = $(pluginlibdir)
 libidle_plugin_la_LIBADD = \
-	libbase-plugin.la
+	liblongcat.la
 libidle_plugin_la_SOURCES = \
 	idle-plugin.h	\
 	idle-plugin.c
 
 libsalut_plugin_ladir = $(pluginlibdir)
 libsalut_plugin_la_LIBADD = \
-	libbase-plugin.la
+	liblongcat.la
 libsalut_plugin_la_SOURCES = \
 	salut-plugin.h	\
 	salut-plugin.c
 
 # plugins stop here
 
-libbase_plugin_ladir = $(pluginlibdir)
-libbase_plugin_la_SOURCES = \
-	base-plugin.h	\
-	base-plugin.c
+liblongcat_ladir = $(pluginlibdir)
+liblongcat_la_SOURCES = \
+	longcat.h	\
+	longcat.c
 
 AM_CFLAGS = \
 		$(ACCOUNTS_CFLAGS) \
diff --git a/src/base-plugin.h b/src/base-plugin.h
deleted file mode 100644
index 82bb261..0000000
--- a/src/base-plugin.h
+++ /dev/null
@@ -1,72 +0,0 @@
-/*
- * base-plugin: An account plugin for telepathy-base
- * Copyright (C) 2009 Collabora Ltd.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- */
-
-#ifndef _BASE_PLUGIN_H_
-#define _BASE_PLUGIN_H_
-
-#include <librtcom-accounts-widgets/rtcom-account-plugin.h>
-
-G_BEGIN_DECLS
-
-#define BASE_TYPE_PLUGIN (base_plugin_get_type ())
-#define BASE_PLUGIN(obj) \
-  (G_TYPE_CHECK_INSTANCE_CAST ((obj), BASE_TYPE_PLUGIN, BasePlugin))
-#define BASE_PLUGIN_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST ((klass), BASE_TYPE_PLUGIN, BasePluginClass))
-#define BASE_IS_PLUGIN(obj) \
-  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BASE_TYPE_PLUGIN))
-#define BASE_IS_PLUGIN_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_TYPE ((klass), BASE_TYPE_PLUGIN))
-#define BASE_PLUGIN_GET_CLASS(obj) \
-  (G_TYPE_INSTANCE_GET_CLASS ((obj), BASE_TYPE_PLUGIN, BasePluginClass))
-
-typedef struct _BasePluginClass BasePluginClass;
-typedef struct _BasePlugin BasePlugin;
-
-struct _BasePluginClass
-{
-  RtcomAccountPluginClass parent_class;
-};
-
-struct _BasePlugin
-{
-  RtcomAccountPlugin parent_instance;
-};
-
-GType base_plugin_get_type (void) G_GNUC_CONST;
-
-typedef void (*BasePluginFillAdvancedTableFunc) (BasePlugin *plugin,
-    RtcomAccountService *service, AccountItem *account, GtkWidget *table);
-
-typedef GtkWidget * (*BasePluginGetPageFunc) (BasePlugin *plugin,
-    RtcomAccountItem *account);
-
-void base_plugin_set_values (BasePlugin *plugin, const gchar *name, guint caps,
-    BasePluginGetPageFunc get_login_page, BasePluginGetPageFunc get_edit_page,
-    BasePluginFillAdvancedTableFunc fill_advanced_table);
-
-typedef void (*BasePluginFillPageFunc) (BasePlugin *plugin,
-    GtkWidget *table);
-
-void base_plugin_fill_page (BasePlugin *plugin, GtkWidget *page,
-    BasePluginFillPageFunc func);
-
-G_END_DECLS
-
-#endif /* _BASE_PLUGIN_H_ */
diff --git a/src/butterfly-plugin.c b/src/butterfly-plugin.c
index 496d4a2..32d6a71 100644
--- a/src/butterfly-plugin.c
+++ b/src/butterfly-plugin.c
@@ -19,7 +19,6 @@
 
 #include <gtk/gtk.h>
 
-#include "base-plugin.h"
 #include "butterfly-plugin.h"
 
 #include <librtcom-accounts-widgets/rtcom-param-string.h>
@@ -33,7 +32,7 @@
 #include <telepathy-glib/connection-manager.h>
 #include <telepathy-glib/util.h>
 
-ACCOUNT_DEFINE_PLUGIN (ButterflyPlugin, butterfly_plugin, BASE_TYPE_PLUGIN);
+ACCOUNT_DEFINE_PLUGIN (ButterflyPlugin, butterfly_plugin, LONGCAT_TYPE);
 
 static void
 butterfly_plugin_init (ButterflyPlugin *self)
@@ -41,7 +40,7 @@ butterfly_plugin_init (ButterflyPlugin *self)
 }
 
 static void
-fill_advanced_table (BasePlugin *plugin,
+fill_advanced_table (Longcat *plugin,
     RtcomAccountService *service,
     AccountItem *account,
     GtkWidget *table)
@@ -121,7 +120,7 @@ fill_advanced_table (BasePlugin *plugin,
 }
 
 static GtkWidget *
-get_login_page (BasePlugin *plugin,
+get_login_page (Longcat *plugin,
     RtcomAccountItem *account)
 {
   const static gchar *invalid_chars_re = "[:'\"<>&;#\\s]";
@@ -136,7 +135,7 @@ get_login_page (BasePlugin *plugin,
 }
 
 static GtkWidget *
-get_edit_page (BasePlugin *plugin,
+get_edit_page (Longcat *plugin,
     RtcomAccountItem *account)
 {
   const static gchar *invalid_chars_re = "[:'\"<>&;#\\s]";
@@ -152,13 +151,13 @@ get_edit_page (BasePlugin *plugin,
 static void
 butterfly_plugin_constructed (GObject *object)
 {
-  BasePlugin *plugin = BASE_PLUGIN (object);
+  Longcat *plugin = LONGCAT (object);
   guint caps;
 
   caps = RTCOM_PLUGIN_CAPABILITY_ADVANCED
     | RTCOM_PLUGIN_CAPABILITY_SCREEN_NAME;
 
-  base_plugin_set_values (plugin, "butterfly", caps, get_login_page,
+  longcat_set_values (plugin, "butterfly", caps, get_login_page,
       get_edit_page, fill_advanced_table);
 
   G_OBJECT_CLASS (butterfly_plugin_parent_class)->constructed (object);
diff --git a/src/butterfly-plugin.h b/src/butterfly-plugin.h
index 17ceb37..a126a41 100644
--- a/src/butterfly-plugin.h
+++ b/src/butterfly-plugin.h
@@ -20,7 +20,7 @@
 #ifndef _BUTTERFLY_PLUGIN_H_
 #define _BUTTERFLY_PLUGIN_H_
 
-#include "base-plugin.h"
+#include "longcat.h"
 
 G_BEGIN_DECLS
 
@@ -41,12 +41,12 @@ typedef struct _ButterflyPlugin ButterflyPlugin;
 
 struct _ButterflyPluginClass
 {
-  BasePluginClass parent_class;
+  LongcatClass parent_class;
 };
 
 struct _ButterflyPlugin
 {
-  BasePlugin parent_instance;
+  Longcat parent_instance;
 };
 
 GType butterfly_plugin_get_type (void) G_GNUC_CONST;
diff --git a/src/haze-plugin.c b/src/haze-plugin.c
index 38b7d6d..68d5547 100644
--- a/src/haze-plugin.c
+++ b/src/haze-plugin.c
@@ -19,7 +19,6 @@
 
 #include <gtk/gtk.h>
 
-#include "base-plugin.h"
 #include "haze-plugin.h"
 
 #include <librtcom-accounts-widgets/rtcom-param-string.h>
@@ -33,7 +32,7 @@
 #include <telepathy-glib/connection-manager.h>
 #include <telepathy-glib/util.h>
 
-ACCOUNT_DEFINE_PLUGIN (HazePlugin, haze_plugin, BASE_TYPE_PLUGIN);
+ACCOUNT_DEFINE_PLUGIN (HazePlugin, haze_plugin, LONGCAT_TYPE);
 
 static void
 haze_plugin_init (HazePlugin *self)
@@ -67,7 +66,7 @@ get_param_name_formatted (const gchar *param_name)
 }
 
 static void
-fill_advanced_table (BasePlugin *plugin,
+fill_advanced_table (Longcat *plugin,
     RtcomAccountService *service,
     AccountItem *account,
     GtkWidget *table)
@@ -271,7 +270,7 @@ clean:
 }
 
 static GtkWidget *
-get_login_page (BasePlugin *plugin,
+get_login_page (Longcat *plugin,
     RtcomAccountItem *account)
 {
   const static gchar *invalid_chars_re = "[:'\"<>&;#\\s]";
@@ -286,7 +285,7 @@ get_login_page (BasePlugin *plugin,
 }
 
 static GtkWidget *
-get_edit_page (BasePlugin *plugin,
+get_edit_page (Longcat *plugin,
     RtcomAccountItem *account)
 {
   const static gchar *invalid_chars_re = "[:'\"<>&;#\\s]";
@@ -302,13 +301,13 @@ get_edit_page (BasePlugin *plugin,
 static void
 haze_plugin_constructed (GObject *object)
 {
-  BasePlugin *plugin = BASE_PLUGIN (object);
+  Longcat *plugin = LONGCAT (object);
   guint caps;
 
   caps = RTCOM_PLUGIN_CAPABILITY_ADVANCED
     | RTCOM_PLUGIN_CAPABILITY_SCREEN_NAME;
 
-  base_plugin_set_values (plugin, "haze", caps,
+  longcat_set_values (plugin, "haze", caps,
       get_login_page, get_edit_page, fill_advanced_table);
 
   G_OBJECT_CLASS (haze_plugin_parent_class)->constructed (object);
diff --git a/src/haze-plugin.h b/src/haze-plugin.h
index ddfd562..894b562 100644
--- a/src/haze-plugin.h
+++ b/src/haze-plugin.h
@@ -20,7 +20,7 @@
 #ifndef _HAZE_PLUGIN_H_
 #define _HAZE_PLUGIN_H_
 
-#include "base-plugin.h"
+#include "longcat.h"
 
 G_BEGIN_DECLS
 
@@ -41,12 +41,12 @@ typedef struct _HazePlugin HazePlugin;
 
 struct _HazePluginClass
 {
-  BasePluginClass parent_class;
+  LongcatClass parent_class;
 };
 
 struct _HazePlugin
 {
-  BasePlugin parent_instance;
+  Longcat parent_instance;
 };
 
 GType haze_plugin_get_type (void) G_GNUC_CONST;
diff --git a/src/idle-plugin.c b/src/idle-plugin.c
index 05c51d8..ca10863 100644
--- a/src/idle-plugin.c
+++ b/src/idle-plugin.c
@@ -19,7 +19,6 @@
 
 #include <gtk/gtk.h>
 
-#include "base-plugin.h"
 #include "idle-plugin.h"
 
 #include <librtcom-accounts-widgets/rtcom-param-string.h>
@@ -34,7 +33,7 @@
 #include <telepathy-glib/connection-manager.h>
 #include <telepathy-glib/util.h>
 
-ACCOUNT_DEFINE_PLUGIN (IdlePlugin, idle_plugin, BASE_TYPE_PLUGIN);
+ACCOUNT_DEFINE_PLUGIN (IdlePlugin, idle_plugin, LONGCAT_TYPE);
 
 static void
 idle_plugin_init (IdlePlugin *self)
@@ -42,7 +41,7 @@ idle_plugin_init (IdlePlugin *self)
 }
 
 static void
-fill_advanced_table (BasePlugin *plugin,
+fill_advanced_table (Longcat *plugin,
     RtcomAccountService *service,
     AccountItem *account,
     GtkWidget *table)
@@ -160,7 +159,7 @@ fill_advanced_table (BasePlugin *plugin,
 }
 
 static void
-fill_page (BasePlugin *plugin,
+fill_page (Longcat *plugin,
     GtkWidget *table)
 {
   GtkWidget *nickname_label, *nickname_entry;
@@ -231,7 +230,7 @@ fill_page (BasePlugin *plugin,
 }
 
 static GtkWidget *
-get_login_page (BasePlugin *plugin,
+get_login_page (Longcat *plugin,
     RtcomAccountItem *account)
 {
   GtkWidget *out;
@@ -241,13 +240,13 @@ get_login_page (BasePlugin *plugin,
       "account", account,
       NULL);
 
-  base_plugin_fill_page (plugin, out, fill_page);
+  longcat_fill_page (plugin, out, fill_page);
 
   return out;
 }
 
 static GtkWidget *
-get_edit_page (BasePlugin *plugin,
+get_edit_page (Longcat *plugin,
     RtcomAccountItem *account)
 {
   GtkWidget *out;
@@ -257,7 +256,7 @@ get_edit_page (BasePlugin *plugin,
       "account", account,
       NULL);
 
-  base_plugin_fill_page (plugin, out, fill_page);
+  longcat_fill_page (plugin, out, fill_page);
 
   return out;
 }
@@ -265,9 +264,9 @@ get_edit_page (BasePlugin *plugin,
 static void
 idle_plugin_constructed (GObject *object)
 {
-  BasePlugin *plugin = BASE_PLUGIN (object);
+  Longcat *plugin = LONGCAT (object);
 
-  base_plugin_set_values (plugin, "idle", RTCOM_PLUGIN_CAPABILITY_ADVANCED,
+  longcat_set_values (plugin, "idle", RTCOM_PLUGIN_CAPABILITY_ADVANCED,
       get_login_page, get_edit_page, fill_advanced_table);
 
   G_OBJECT_CLASS (idle_plugin_parent_class)->constructed (object);
diff --git a/src/idle-plugin.h b/src/idle-plugin.h
index af51414..6bb8fa4 100644
--- a/src/idle-plugin.h
+++ b/src/idle-plugin.h
@@ -20,7 +20,7 @@
 #ifndef _IDLE_PLUGIN_H_
 #define _IDLE_PLUGIN_H_
 
-#include "base-plugin.h"
+#include "longcat.h"
 
 G_BEGIN_DECLS
 
@@ -41,12 +41,12 @@ typedef struct _IdlePlugin IdlePlugin;
 
 struct _IdlePluginClass
 {
-  BasePluginClass parent_class;
+  LongcatClass parent_class;
 };
 
 struct _IdlePlugin
 {
-  BasePlugin parent_instance;
+  Longcat parent_instance;
 };
 
 GType idle_plugin_get_type (void) G_GNUC_CONST;
diff --git a/src/longcat.h b/src/longcat.h
new file mode 100644
index 0000000..43a31e2
--- /dev/null
+++ b/src/longcat.h
@@ -0,0 +1,72 @@
+/*
+ * longcat: An account plugin for a telepathy connection manager
+ * Copyright (C) 2009 Collabora Ltd.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef _LONGCAT_H_
+#define _LONGCAT_H_
+
+#include <librtcom-accounts-widgets/rtcom-account-plugin.h>
+
+G_BEGIN_DECLS
+
+#define LONGCAT_TYPE (longcat_get_type ())
+#define LONGCAT(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST ((obj), LONGCAT_TYPE, Longcat))
+#define LONGCAT_CLASS(klass) \
+  (G_TYPE_CHECK_CLASS_CAST ((klass), LONGCAT_TYPE, LongcatClass))
+#define IS_LONGCAT(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LONGCAT_TYPE))
+#define IS_LONGCAT_CLASS(klass) \
+  (G_TYPE_CHECK_CLASS_TYPE ((klass), LONGCAT_TYPE))
+#define LONGCAT_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_CLASS ((obj), LONGCAT_TYPE, LongcatClass))
+
+typedef struct _LongcatClass LongcatClass;
+typedef struct _Longcat Longcat;
+
+struct _LongcatClass
+{
+  RtcomAccountPluginClass parent_class;
+};
+
+struct _Longcat
+{
+  RtcomAccountPlugin parent_instance;
+};
+
+GType longcat_get_type (void) G_GNUC_CONST;
+
+typedef void (*LongcatFillAdvancedTableFunc) (Longcat *plugin,
+    RtcomAccountService *service, AccountItem *account, GtkWidget *table);
+
+typedef GtkWidget * (*LongcatGetPageFunc) (Longcat *plugin,
+    RtcomAccountItem *account);
+
+void longcat_set_values (Longcat *plugin, const gchar *name, guint caps,
+    LongcatGetPageFunc get_login_page, LongcatGetPageFunc get_edit_page,
+    LongcatFillAdvancedTableFunc fill_advanced_table);
+
+typedef void (*LongcatFillPageFunc) (Longcat *plugin,
+    GtkWidget *table);
+
+void longcat_fill_page (Longcat *plugin, GtkWidget *page,
+    LongcatFillPageFunc func);
+
+G_END_DECLS
+
+#endif /* _LONGCAT_H_ */
diff --git a/src/salut-plugin.c b/src/salut-plugin.c
index dc06dbe..9fa53fe 100644
--- a/src/salut-plugin.c
+++ b/src/salut-plugin.c
@@ -19,7 +19,6 @@
 
 #include <gtk/gtk.h>
 
-#include "base-plugin.h"
 #include "salut-plugin.h"
 
 #include <librtcom-accounts-widgets/rtcom-param-string.h>
@@ -34,7 +33,7 @@
 #include <telepathy-glib/connection-manager.h>
 #include <telepathy-glib/util.h>
 
-ACCOUNT_DEFINE_PLUGIN (SalutPlugin, salut_plugin, BASE_TYPE_PLUGIN);
+ACCOUNT_DEFINE_PLUGIN (SalutPlugin, salut_plugin, LONGCAT_TYPE);
 
 static void
 salut_plugin_init (SalutPlugin *self)
@@ -42,7 +41,7 @@ salut_plugin_init (SalutPlugin *self)
 }
 
 static void
-fill_advanced_table (BasePlugin *plugin,
+fill_advanced_table (Longcat *plugin,
     RtcomAccountService *service,
     AccountItem *account,
     GtkWidget *table)
@@ -143,7 +142,7 @@ fill_advanced_table (BasePlugin *plugin,
 }
 
 static void
-fill_page (BasePlugin *plugin,
+fill_page (Longcat *plugin,
     GtkWidget *table)
 {
   GtkWidget *first_name_label, *first_name_entry;
@@ -206,7 +205,7 @@ fill_page (BasePlugin *plugin,
 }
 
 static GtkWidget *
-get_login_page (BasePlugin *plugin,
+get_login_page (Longcat *plugin,
     RtcomAccountItem *account)
 {
   GtkWidget *out;
@@ -216,13 +215,13 @@ get_login_page (BasePlugin *plugin,
       "account", account,
       NULL);
 
-  base_plugin_fill_page (plugin, out, fill_page);
+  longcat_fill_page (plugin, out, fill_page);
 
   return out;
 }
 
 static GtkWidget *
-get_edit_page (BasePlugin *plugin,
+get_edit_page (Longcat *plugin,
     RtcomAccountItem *account)
 {
   GtkWidget *out;
@@ -232,7 +231,7 @@ get_edit_page (BasePlugin *plugin,
       "account", account,
       NULL);
 
-  base_plugin_fill_page (plugin, out, fill_page);
+  longcat_fill_page (plugin, out, fill_page);
 
   return out;
 }
@@ -240,9 +239,9 @@ get_edit_page (BasePlugin *plugin,
 static void
 salut_plugin_constructed (GObject *object)
 {
-  BasePlugin *plugin = BASE_PLUGIN (object);
+  Longcat *plugin = LONGCAT (object);
 
-  base_plugin_set_values (plugin, "salut", RTCOM_PLUGIN_CAPABILITY_ADVANCED,
+  longcat_set_values (plugin, "salut", RTCOM_PLUGIN_CAPABILITY_ADVANCED,
       get_login_page, get_edit_page, fill_advanced_table);
 
   G_OBJECT_CLASS (salut_plugin_parent_class)->constructed (object);
diff --git a/src/salut-plugin.h b/src/salut-plugin.h
index 6e9eb71..6b1be80 100644
--- a/src/salut-plugin.h
+++ b/src/salut-plugin.h
@@ -20,7 +20,7 @@
 #ifndef _SALUT_PLUGIN_H_
 #define _SALUT_PLUGIN_H_
 
-#include "base-plugin.h"
+#include "longcat.h"
 
 G_BEGIN_DECLS
 
@@ -41,12 +41,12 @@ typedef struct _SalutPlugin SalutPlugin;
 
 struct _SalutPluginClass
 {
-  BasePluginClass parent_class;
+  LongcatClass parent_class;
 };
 
 struct _SalutPlugin
 {
-  BasePlugin parent_instance;
+  Longcat parent_instance;
 };
 
 GType salut_plugin_get_type (void) G_GNUC_CONST;

diff --git a/src/base-plugin.c b/src/longcat.c
similarity index 88%
rename from src/base-plugin.c
rename to src/longcat.c
index 05cb23c..672fec5 100644
--- a/src/base-plugin.c
+++ b/src/longcat.c
@@ -1,5 +1,5 @@
 /*
  * base-plugin: An account plugin for a telepathy connection manager
  * Copyright (C) 2009 Collabora, Ltd.
  *
  * This library is free software; you can redistribute it and/or
@@ -21,7 +21,7 @@
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 
-#include "base-plugin.h"
+#include "longcat.h"
 
 #include <librtcom-accounts-widgets/rtcom-account-item.h>
 #include <librtcom-accounts-widgets/rtcom-login.h>
@@ -38,28 +38,28 @@
 
 #define H_(x) dgettext("hildon-libs", x)
 
-G_DEFINE_TYPE (BasePlugin, base_plugin, RTCOM_TYPE_ACCOUNT_PLUGIN);
+G_DEFINE_TYPE (Longcat, longcat, RTCOM_TYPE_ACCOUNT_PLUGIN);
 
-#define BASE_PLUGIN_PRIV(ap) (G_TYPE_INSTANCE_GET_PRIVATE ((ap), \
-            BASE_TYPE_PLUGIN, BasePluginPrivate))
+#define LONGCAT_PRIV(ap) (G_TYPE_INSTANCE_GET_PRIVATE ((ap), \
+            LONGCAT_TYPE, LongcatPrivate))
 
 typedef struct {
   gchar *name;
   guint caps;
-  BasePluginGetPageFunc get_login_page;
-  BasePluginGetPageFunc get_edit_page;
-  BasePluginFillAdvancedTableFunc fill_advanced_table;
-} BasePluginPrivate;
+  LongcatGetPageFunc get_login_page;
+  LongcatGetPageFunc get_edit_page;
+  LongcatFillAdvancedTableFunc fill_advanced_table;
+} LongcatPrivate;
 
 static void
-base_plugin_init (BasePlugin *self)
+longcat_init (Longcat *self)
 {
 }
 
 static void
-base_plugin_finalize (GObject *object)
+longcat_finalize (GObject *object)
 {
-  BasePluginPrivate *priv = BASE_PLUGIN_PRIV (object);
+  LongcatPrivate *priv = LONGCAT_PRIV (object);
 
   if (priv->name != NULL)
     {
@@ -69,10 +69,10 @@ base_plugin_finalize (GObject *object)
 }
 
 static void
-base_plugin_constructed (GObject *object)
+longcat_constructed (GObject *object)
 {
   RtcomAccountPlugin *rtcom_plugin = RTCOM_ACCOUNT_PLUGIN (object);
-  BasePluginPrivate *priv = BASE_PLUGIN_PRIV (object);
+  LongcatPrivate *priv = LONGCAT_PRIV (object);
   GList *profiles, *list;
   gchar *cfg_name;
 
@@ -249,10 +249,10 @@ create_advanced_settings_page (RtcomDialogContext *context)
       GtkWidget *vbox;
       GtkWidget *table;
       GHashTable *advanced_settings = NULL;
-      BasePlugin *plugin;
-      BasePluginPrivate *priv;
+      Longcat *plugin;
+      LongcatPrivate *priv;
 
-      xml = glade_xml_new (PLUGIN_XML_DIR "/base-advanced.glade", NULL,
+      xml = glade_xml_new (PLUGIN_XML_DIR "/longcat-advanced.glade", NULL,
           GETTEXT_PACKAGE);
       rtcom_dialog_context_take_obj (context, G_OBJECT (xml));
       dialog = glade_xml_get_widget (xml, "advanced");
@@ -298,8 +298,8 @@ create_advanced_settings_page (RtcomDialogContext *context)
       vbox = glade_xml_get_widget (xml, "vbox");
       gtk_box_pack_start (GTK_BOX (vbox), table, TRUE, TRUE, 0);
 
-      plugin = BASE_PLUGIN (account_item_get_plugin (account));
-      priv = BASE_PLUGIN_PRIV (plugin);
+      plugin = LONGCAT (account_item_get_plugin (account));
+      priv = LONGCAT_PRIV (plugin);
 
       if (priv->fill_advanced_table != NULL)
         priv->fill_advanced_table (plugin, RTCOM_ACCOUNT_SERVICE (service),
@@ -344,7 +344,7 @@ context_init (RtcomAccountPlugin *plugin,
   gboolean editing;
   GtkWidget *page = NULL;
   RtcomAccountItem *account;
-  BasePluginPrivate *priv = BASE_PLUGIN_PRIV (plugin);
+  LongcatPrivate *priv = LONGCAT_PRIV (plugin);
 
   g_idle_add (create_advanced_settings_page_idle, context);
 
@@ -357,7 +357,7 @@ context_init (RtcomAccountPlugin *plugin,
       g_debug ("%s plugin builds edit page...", plugin->name);
 
       if (priv->get_edit_page != NULL)
-        page = priv->get_edit_page (BASE_PLUGIN (plugin), account);
+        page = priv->get_edit_page (LONGCAT (plugin), account);
 
       g_assert (RTCOM_IS_EDIT (page));
 
@@ -369,7 +369,7 @@ context_init (RtcomAccountPlugin *plugin,
       g_debug ("%s plugin builds start page...", plugin->name);
 
       if (priv->get_login_page != NULL)
-        page = priv->get_login_page (BASE_PLUGIN (plugin), account);
+        page = priv->get_login_page (LONGCAT (plugin), account);
 
       g_assert (RTCOM_IS_LOGIN (page));
 
@@ -381,28 +381,28 @@ context_init (RtcomAccountPlugin *plugin,
 }
 
 static void
-base_plugin_class_init (BasePluginClass *klass)
+longcat_class_init (LongcatClass *klass)
 {
   GObjectClass* object_class = G_OBJECT_CLASS (klass);
   RtcomAccountPluginClass *rtcom_class = RTCOM_ACCOUNT_PLUGIN_CLASS (klass);
 
-  object_class->constructed = base_plugin_constructed;
-  object_class->finalize = base_plugin_finalize;
+  object_class->constructed = longcat_constructed;
+  object_class->finalize = longcat_finalize;
 
   rtcom_class->context_init = context_init;
 
-  g_type_class_add_private (object_class, sizeof (BasePluginPrivate));
+  g_type_class_add_private (object_class, sizeof (LongcatPrivate));
 }
 
 void
-base_plugin_set_values (BasePlugin *plugin,
+longcat_set_values (Longcat *plugin,
     const gchar *name,
     guint caps,
-    BasePluginGetPageFunc get_login_page,
-    BasePluginGetPageFunc get_edit_page,
-    BasePluginFillAdvancedTableFunc fill_advanced_table)
+    LongcatGetPageFunc get_login_page,
+    LongcatGetPageFunc get_edit_page,
+    LongcatFillAdvancedTableFunc fill_advanced_table)
 {
-  BasePluginPrivate *priv = BASE_PLUGIN_PRIV (plugin);
+  LongcatPrivate *priv = LONGCAT_PRIV (plugin);
 
   g_free (priv->name);
   priv->name = g_strdup (name);
@@ -413,9 +413,9 @@ base_plugin_set_values (BasePlugin *plugin,
 }
 
 void
-base_plugin_fill_page (BasePlugin *plugin,
+longcat_fill_page (Longcat *plugin,
     GtkWidget *page,
-    BasePluginFillPageFunc func)
+    LongcatFillPageFunc func)
 {
   GList *children;
   GtkWidget *area, *main_align, *viewport, *main_pane, *login_table;
@@ -1,5 +1,5 @@
 /*
- * base-plugin: An account plugin for a telepathy connection manager
+ * longcat: An account plugin for a telepathy connection manager
  * Copyright (C) 2009 Collabora, Ltd.
  *